@@ -23,13 +23,15 @@
 #' @param true_est True estimate to assess E-value for. Default to 1 on risk scale
 #' to assess against null value. Set to a different value to assess for non-null
 #' hypotheses.
-#' 
+#'
 #' @return A matrix with the observed point estimate and closest confidence interval to
 #' the null hypothesis, expressed as a relative risk, and their corresponding E-value.
 #'
+#' @family confounding
+#'
 #' @references VanderWeele T.J and Ding P. Sensitivity analysis in observational research:
 #' Introducing the E-value. Annals of Internal Medicine 2017;167:268-274.
-#' 
+#'
 #' @examples
 #' # The data for this example come from:
 #' # Victoria C.G., Smith P.G., Vaughan J.P., Nobre L.C., Lombardi C., Teixeira A.M.
@@ -40,7 +42,7 @@
 #' confounders.evalue(est = 3.9, type = "RR")
 #'
 #' # The data for this example come from:
-#' # Oddy W.H, Smith G.J., Jacony P. 
+#' # Oddy W.H, Smith G.J., Jacony P.
 #' # A possible strategy for developing a model to account for attrition bias in a
 #' # longitudinal cohort to investigate associations between exclusive breastfeeding and
 #' # overweight and obesity at 20 years.
@@ -59,42 +61,39 @@ confounders.evalue <- function(est,
                                upper_ci = NULL,
                                sd = NA,
                                type = c("RR", "ORc", "HRc", "diff_RR", "diff_OR"),
-                               true_est = 1){
+                               true_est = 1) {
     if (length(type) > 1)
-        stop('Choose between RR, ORc, HRc, diff_RR, or diff_OR implementation.')
+        stop(cli::format_error(c("x" = "Choose between RR, ORc, HRc, diff_RR, or diff_OR implementation.")))
 
     if (!(type %in% c("diff_RR", "diff_OR")) & est < 0)
-        stop('Association cannot be negative.')
+        stop(cli::format_error(c("x" = "Association cannot be negative.")))
 
     if ((type != "diff_RR" | type != "diff_OR") & est == 1)
-        stop('Association = 1! No E-value.')
+        stop(cli::format_error(c("x" = "Association = 1! No E-value.")))
 
-    if(!is.null(lower_ci) & !is.null(upper_ci)){
+    if (!is.null(lower_ci) & !is.null(upper_ci)) {
         if (!is.na(lower_ci) & !is.na(upper_ci) & lower_ci > upper_ci)
-            stop("Lower confidence interval should be less than the upper limit.")
-        if ((type != "diff") & (!is.na(lower_ci) & est < lower_ci) |
-            (!is.na(upper_ci) & est > upper_ci))
-            stop("Provided association is not within provided confidence interval.")        
+            stop(cli::format_error(c("i" = "Lower confidence interval should be less than the upper limit.")))
+        if ((type != "diff") & (!is.na(lower_ci) & est < lower_ci) | (!is.na(upper_ci) & est > upper_ci))
+            stop(cli::format_error(c("i" = "Provided association is not within provided confidence interval.")))
         if ((type != "diff_RR" | type != "diff_OR") & true_est == 1 &
-            (!is.na(lower_ci) & lower_ci < 1) &
-            (!is.na(upper_ci) & 1 < upper_ci))
-            stop("True association within provided confidence interval: E-value = 1.")
+            (!is.na(lower_ci) & lower_ci < 1) & (!is.na(upper_ci) & 1 < upper_ci))
+            stop(cli::format_error(c("i" = "True association within provided confidence interval: E-value = 1.")))
     }
 
     if ((type != "diff_RR" | type != "diff_OR") & true_est < 0)
-        stop("True association should not be negative.")
-    
+        stop(cli::format_error(c("x" = "True association should not be negative.")))
+
     if (!inherits(est, "numeric"))
-        stop("Please provide a valid value for association measure.")
+        stop(cli::format_error(c("x" = "Please provide a valid value for association measure.")))
 
     if ((type == "diff_RR" | type == "diff_OR") & is.na(sd))
-        stop("Please provide sd.")
+        stop(cli::format_error(c("i" = "Please provide sd.")))
 
     if (((type == "diff_RR" | type == "diff_OR") & !is.na(sd)) & sd < 0)
-        stop("Standardized SE cannot be negative.")
+        stop(cli::format_error(c("x" = "Standardized SE cannot be negative.")))
 
-    if ((type != "diff_RR" | type != "diff_OR") &
-        (!is.null(lower_ci) | !is.null(upper_ci))) {
+    if ((type != "diff_RR" | type != "diff_OR") & (!is.null(lower_ci) | !is.null(upper_ci))) {
         closest_ci <- closest(c(lower_ci, upper_ci), true_est)
     } else {
         closest_ci <- NA
@@ -105,20 +104,20 @@ confounders.evalue <- function(est,
     } else if (type == "diff_RR") {
         tab <- c(exp(0.91*est),
                  closest(c(exp(0.91*est - 1.78*sd), exp(0.91*est + 1.78*sd)),
-                          true_est))
+                         true_est))
     } else if (type == "diff_OR") {
         tab <- c(exp(1.81*est),
                  closest(c(exp(1.81*est - 3.55*sd), exp(1.81*est + 3.55*sd)),
-                          true_est))
+                         true_est))
     }
 
     .compute_evalue <- function(x, true_x) {
         if (is.na(x)) return(NA)
-        
+
         if (true_x != 1) {
             x = true_x / x
         }
-        
+
         if (x < 1) {
             x <- 1 / x
         }
