@@ -1,7 +1,7 @@
 context("check bias due to unmeasured confounders based on external adjustment")
 
 test_that("correct if null bias parameters", {
-    expect_output(confounders.ext(RR = 1))
+    expect_output(confounders.ext(RR = 1), regexp = NA)
 })
 
 test_that("correct number of arguments for bias parameters", {
@@ -36,8 +36,7 @@ test_that("true RR > 0", {
 
 test_that("results ok!", {
     model <- confounders.ext(RR = 1,
-                             bias_parms = c(0.1, 0.9, 0.1, 0.4),
-                             print = FALSE)
-    expect_equal(as.numeric(model[6]), 1.0093, tolerance = 1e-4)
-    expect_equal(as.numeric(model[7]), 0.9328, tolerance = 1e-4)
+                             bias_parms = c(0.1, 0.9, 0.1, 0.4))
+    expect_equal(as.numeric(model[[3]][1]), 1.0093, tolerance = 1e-4)
+    expect_equal(as.numeric(model[[3]][2]), 0.9328, tolerance = 1e-4)
 })
